@@ -1,3 +1,3 @@
 from TMotorCANControl.mit_can import TMotorManager_mit_can
 from TMotorCANControl.servo_can import TMotorManager_servo_can
-from TMotorCANControl.servo_serial import TMotorManager_servo_serial
\ No newline at end of file
+from TMotorCANControl.servo_serial import TMotorManager_servo_serial, Servo_Params_Serial
\ No newline at end of file
